@@ -17,7 +17,7 @@ Latest Slimjet Browser (run again for updates)
 64
 </installable>
 
-<screenshot>https://www.slimjet.com/en/images/newtab.jpg</screenshot>
+<screenshot>none</screenshot>
 
 <preinstall>
 x-terminal-emulator -e wget http://www.slimjet.com/release/slimjet_amd64.deb
